==> blobAndConquer-0.91-1.tar.gz: blobAndConquer-0.91/src/combat/weapons.h <==
/*
Copyright (C) 2006 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include "../headers.h"

extern void addDesimilatorBeam(Unit *owner, Vector origin, Vector destination);
extern void addIceShot(Entity *owner, Vector origin, Vector destination);
extern void addFlame(Entity *owner, Vector origin, Vector destination);
extern void addNormalBullet(Entity *owner, WeaponDef *definition, Vector origin, Vector destination);
extern void addPellet(Unit *owner, WeaponDef *definition, Vector origin, Vector destination);
extern void throwGrenade(Unit *owner, Vector origin, Vector destination);
extern void fireWeaponBeam(Unit *owner, WeaponDef *weaponDef, Vector origin, Vector destination);
extern void addLauncherShot(Entity *owner, WeaponDef *weaponDef, Vector origin, Vector destination);
extern void addRocket(Entity *owner, Vector origin, Vector destination);
extern void addMiniMine(Entity *owner, Vector position, Vector destination);
extern List *loadProperties(char *filename, bool fromPak);
extern int getSoundDistanceFromPlayer(Vector position);

extern Audio *audio;
extern Camera *camera;
extern Engine *engine;
extern Game *game;
extern Unit *player;

==> blobAndConquer-0.93-2.tar.gz: blobAndConquer-0.93/src/combat/weapons.h <==
/*
Copyright (C) 2006 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include "../headers.h"

extern void addDesimilatorBeam(Unit *owner, Vector origin, Vector destination);
extern void addIceShot(Entity *owner, Vector origin, Vector destination);
extern void addFlame(Entity *owner, Vector origin, Vector destination);
extern void addNormalBullet(Entity *owner, WeaponDef *definition, Vector origin, Vector destination);
extern void addPellet(Unit *owner, WeaponDef *definition, Vector origin, Vector destination);
extern void throwGrenade(Unit *owner, Vector origin, Vector destination);
extern void fireWeaponBeam(Unit *owner, WeaponDef *weaponDef, Vector origin, Vector destination);
extern void addLauncherShot(Entity *owner, WeaponDef *weaponDef, Vector origin, Vector destination);
extern void addRocket(Entity *owner, Vector origin, Vector destination);
extern void addMiniMine(Entity *owner, Vector position, Vector destination);
extern List *loadProperties(const char *filename, bool fromPak);
extern int getSoundDistanceFromPlayer(Vector position);

extern Audio *audio;
extern Camera *camera;
extern Engine *engine;
extern Game *game;
extern Unit *player;
